GPTStreamDecoder class

Stream transformer for decoding OpenAI SSE (Server-Sent Events) streams.

Constructors

GPTStreamDecoder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

decoder StreamTransformer<String, String>
Returns a stream transformer that decodes SSE data events.
no setter